@@ -234,7 +234,8 @@ class TextValueSerializer(ValueSerializer):
     value = serializers.CharField(
         required=False,
         allow_blank=True,
-        help_text='Field value'
+        help_text='Field value',
+        trim_whitespace=False
     )
 
     field = serializers.PrimaryKeyRelatedField(
@@ -288,7 +289,7 @@ class BooleanValueSerializer(ValueSerializer):
         )
 
 
-class ChoiceSerializer(serializers.ModelSerializer):
+class ChoiceSerializer(MaskFieldSerializer):
 
     name = serializers.CharField(
         help_text='Choice label'
@@ -711,6 +712,31 @@ class ItemSerializer(MaskFieldSerializer, TrackTimeSerializer):
         )
 
 
+class FieldFilterSerializer(serializers.Serializer):
+    item_schema_id__in = serializers.ListSerializer(
+        child=serializers.IntegerField(),
+        required=False
+    )
+
+
+class ValueFilterSerializer(serializers.Serializer):
+    item_id__in = serializers.ListSerializer(
+        child=serializers.IntegerField(),
+        required=False
+    )
+
+
+class ChoiceFilterSerializer(serializers.Serializer):
+    field_id__in = serializers.ListSerializer(
+        child=serializers.IntegerField(),
+        required=False
+    )
+    field__item_schema_id__in = serializers.ListSerializer(
+        child=serializers.IntegerField(),
+        required=False
+    )
+
+
 class ItemFilterSerializer(serializers.Serializer):
 
     order_by = serializers.CharField(required=False)
@@ -727,5 +753,33 @@ class ItemFilterSerializer(serializers.Serializer):
     created_at__gte = serializers.DateTimeField(required=False)
 
 
+class ItemSchemaFilterSerializer(serializers.Serializer):
+
+    order_by = serializers.ChoiceField(
+        required=False,
+        choices=[
+            'name',
+            'category',
+            'created_at',
+            'updated_at',
+            '-name',
+            '-category',
+            '-created_at',
+            '-updated_at'
+        ]
+    )
+
+    name__icontains = serializers.CharField(required=False)
+
+    category_id__in = serializers.ListSerializer(
+        child=serializers.IntegerField(),
+        required=False
+    )
+
+    created_at__lte = serializers.DateTimeField(required=False)
+
+    created_at__gte = serializers.DateTimeField(required=False)
+
+
 class ImportSerializer(serializers.Serializer):
     file = serializers.FileField()
